# GraPhysio
GraPhysio is a graphical time series visualizer created for physiologic
data signals from ICU patient monitors. It is however not limited to this.
It currently supports reading from CSV files.
It can handle low frequency and high frequency data as well as aggregating
and synchronizing signals from different sources.
GraPhysio supports basic mathematical operations and filters and can help
selecting and exporting time periods.
Performance is good depending on your hardware for files up to 1 GB.

## Install instructions
To make GraPhysio work you need Python 3.6 or greater.

You can then install the latest version of GraPhysio by tying the
following command:

> python -m pip install graphysio

You can launch GraPhysio by typing:

> python -m graphysio

Alternatively, on Windows, you can use the release binaries.
